class BaseValueCheck():
    ##################################################################################################
    # Constructor
    ##################################################################################################
    def __init__(self, column_value):
        self.column_value = column_value

    ##################################################################################################
    # Properties
    ##################################################################################################
    column_value = None
